@@ -61,7 +61,8 @@ def types(c: Context, show_information: bool = False):
 
     tmp_handler = NamedTemporaryFile()
     res = cast(
-        Result, c.run(f'poetry run pyright {directories} --outputjson > {tmp_handler.name}', echo=True, hide=True, warn=True),
+        Result,
+        c.run(f'poetry run pyright {directories} --outputjson > {tmp_handler.name}', echo=True, hide=True, warn=True),
     )
 
     results = PyrightOutput.parse_raw(tmp_handler.read())
