@@ -5,13 +5,12 @@ from invoke import Collection, Context, run, task
 from outcome.read_toml import lib as read_toml
 from outcome.utils.env import is_ci
 
-from outcome.devkit.invoke import env
-from outcome.devkit.invoke.tasks import package
+from outcome.devkit.invoke import app, env
 
 
 @env.add
 def build_system_requirements(e: env.Env) -> Optional[str]:
-    return read_toml.read_from_file(env.r(package.pyproject_file), 'build-system.requires')
+    return read_toml.read_from_file(env.r(app.pyproject_file), 'build-system.requires')
 
 
 @env.add
@@ -22,12 +21,14 @@ def poetry_ld_flags_from_brew(e: env.Env) -> str:
 
 
 @task
-def build_system(c: Context):
+def build_system(c: Context, skip_pre_commit: bool = False):
     """Install essential build system components."""
     requirements = env.r(build_system_requirements)
     c.run(f'pip install "{requirements}"')
 
-    if not is_ci():
+    info = app.get_git_info()
+
+    if not is_ci() and not skip_pre_commit and info is not None:
         # Setup pre-commit
         c.run('pre-commit install -t pre-commit')
         c.run('pre-commit install -t pre-push')
@@ -61,7 +62,8 @@ def dev(c: Context):
 @task(build_system)
 def production(c: Context):
     """Install the dependencies for production environments."""
-    c.run('poetry config virtualenvs.create false')
+    c.run('poetry config virtualenvs.create true')
+    c.run('poetry config virtualenvs.in-project true')
     c.run('poetry install --no-dev --no-interaction --no-ansi  --remove-untracked')
 
 
